@@ -10,14 +10,14 @@ import logging
 import os
 import xml.etree.ElementTree as ET
 
-from . import (check_artwork, check_dependencies, check_entrypoint,
-               check_files, check_addon_branches, check_py3_compatibility,
-               check_string, check_url, common, handle_files,
-               schema_validation, ValidKodiVersions)
+from . import (check_allowed_versions, check_artwork, check_dependencies,
+               check_entrypoint, check_files, check_addon_branches,
+               check_py3_compatibility, check_string, check_url, common,
+               handle_files, schema_validation, ValidKodiVersions)
 from .addons.Addon import Addon
 from .addons.Repository import Repository
 from .versions import KodiVersion
-from .record import INFORMATION, Record
+from .record import INFORMATION, PROBLEM, Record
 from .report import Report
 
 ROOT_URL = "http://mirrors.kodi.tv/addons/{branch}/addons.xml.gz"
@@ -40,8 +40,14 @@ def start(addon_path, args, all_repo_addons, config=None):
 
     repo_addons = all_repo_addons[args.branch]
     addon_xml_path = os.path.join(addon_path, "addon.xml")
-    parsed_xml = ET.parse(addon_xml_path).getroot()
+    try:
+        parsed_xml = ET.parse(addon_xml_path).getroot()
+    except ET.ParseError:
+        addon_report.add(
+                Record(PROBLEM, "Invalid XML data in addon.xml"))
 
+    # check if provided version for the addon is allowed
+    check_allowed_versions.check_version(addon_report, parsed_xml)
     # Extract common path from addon paths
     # All paths will be printed relative to this path
     common.REL_PATH = os.path.split(addon_path[:-1])[0]
