@@ -1,3 +1,11 @@
+"""
+    Copyright (C) 2017-2018 Team Kodi
+    This file is part of Kodi - kodi.tv
+
+    SPDX-License-Identifier: GPL-3.0-only
+    See LICENSES/README.md for more information.
+"""
+
 import inspect
 from abc import ABC
 
@@ -8,7 +16,7 @@ class Reporter(ABC):
         pass
 
 
-class ReportManager(object):
+class ReportManager():
     reporters = {}
 
     @classmethod
